@@ -1,5 +1,5 @@
 # GNU Solfege - eartraining for GNOME
-# Copyright (C) 2000, 2001, 2002  Tom Cato Amundsen
+# Copyright (C) 2000, 2001, 2002, 2003  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -25,3 +25,11 @@ print "****************"
 print "using gnome emu"
 print "****************"
 
+def program_init(appname, version):
+    print "dummy program_init(%s, %s)" % (appname, version)
+
+def program_get():
+    class Dummy:
+        def parse_args(self):
+            print "dummy program.parse_args()"
+    return Dummy()
