@@ -1,5 +1,5 @@
 # GNU Solfege - eartraining for GNOME
-# Copyright (C) 2000, 2001, 2002  Tom Cato Amundsen
+# Copyright (C) 2000, 2001, 2002, 2003  Tom Cato Amundsen
 # Copyright (C) 2001 Joe Lee
 #
 # This program is free software; you can redistribute it and/or modify
@@ -20,12 +20,17 @@ import winmidi
 
 class WinSynth:
     NUM_CHANNELS = 16
-    def __init__(self, synthnum, verbose_init):
-        self.__driver = winmidi.Winmidi(synthnum)
+    def __init__(self, devnum, verbose_init):
+        self.__driver = winmidi.Winmidi(devnum)
+        self.m_type_major = "win32" #FIXME
+        self.m_devnum = devnum
         if verbose_init:
             print "Solfege will use Windows multimedia output."
     def close(self):
         self.__driver = None
+    def stop(self):
+        # dummy function
+        pass
     def play_track(self, track):
         if self.__driver is None:
             raise RuntimeError, "Attempted to use synth after closing."
