@@ -359,7 +359,7 @@ class ConfigWindow(gnome.ui.PropertyBox, cfg.ConfigUtils):
             self.set_int('config/preferred_instrument',
                          self.g_instrsel.m_instrument)
             self.set_int('config/preferred_instrument_velocity',
-                         self.g_instrsel.g_velocity.get_value())
+                         self.g_instrsel.g_velocity.get_value_as_int())
         if pagenum == 1:
             self.set_string('user/lowest_pitch',
                 mpd.int_to_notename(self.g_lowest_singable.get_value()))
@@ -434,24 +434,27 @@ class ConfigWindow(gnome.ui.PropertyBox, cfg.ConfigUtils):
                 except (soundcard.SoundInitException, OSError), e:
                     self.m_app.display_sound_init_error_message(e)
                     return
-            else:
+            else: # no sound
                 assert self.g_fakesynth_radio.get_active()
                 soundcard.initialise_using_fake_synth(0)
             if self.g_midiplayer_radio.get_active():
                 self.set_string("sound/type", "external-midiplayer")
             elif self.g_device_radio.get_active():
-                self.set_string("sound/type", "sequencer-device")
+                if sys.platform == "win32":
+                    self.set_string("sound/type", "winsynth")
+                else:
+                    self.set_string("sound/type", "sequencer-device")
             else:
                 assert self.g_fakesynth_radio.get_active()
                 self.set_string("sound/type", "fake-synth")
             if sys.platform != 'win32':
                 self.set_string("sound/device_file", self.g_device_entry.get_text())
                 self.set_string("sound/card_info", card_info)
-                if soundcard.synth.m_type_major == "OSS":
-                    self.set_int("sound/synth_number", soundcard.synth.m_devnum)
-                    # we set the spin just in case m_devnum was changed by the
-                    # soundcard setup code, if it was out of range
-                    self.g_synth_num.set_value(soundcard.synth.m_devnum)
+            if soundcard.synth.m_type_major not in ('Midifile', 'Fake'):
+                self.set_int("sound/synth_number", soundcard.synth.m_devnum)
+                # we set the spin just in case m_devnum was changed by the
+                # soundcard setup code, if it was out of range
+                self.g_synth_num.set_value(soundcard.synth.m_devnum)
             self.set_string("sound/commandline",
                             self.g_midiplayer_entry.get_text())
         if pagenum == -1:
