@@ -1,5 +1,5 @@
 # GNU Solfege - eartraining for GNOME
-# Copyright (C) 2000, 2001, 2002  Tom Cato Amundsen
+# Copyright (C) 2000, 2001, 2002, 2003  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -31,9 +31,11 @@ class History:
         # First we remove if necessary
         self.m_list = self.m_list[:self.m_idx + 1]
         # we don't want duplicate entries in the history
-        if not self.m_list or self.m_list[-1] != data:
-            self.m_list.append(data)
+        if not self.m_list or self.m_list[-1][0] != data:
+            self.m_list.append([data, None])
             self.m_idx = self.m_idx + 1
+    def set_adj_of_current(self, adj):
+        self.m_list[self.m_idx][1] = adj
     def back(self):
         if self.m_idx > 0:
             self.m_idx = self.m_idx - 1
