@@ -17,7 +17,7 @@
 
 from __future__ import division
 
-import gtk, gnome.ui, gnome.canvas, types
+import gtk, gnome.ui, gnome.canvas
 import mpd
 import soundcard
 import cfg
@@ -118,13 +118,14 @@ class IntervalPianoWidget(PianoKeyboard):
         self.m_clicked_tones = [tone.semitone_pitch()]
         self.mark(self.m_clicked_tones[-1])
     def on_button_press_event(self, group, event, midi_int):
+        """
+        The callback function is only called if we have an interval.
+        """
         if self.m_clicked_tones:
             interval = midi_int - self.m_clicked_tones[-1]
             if event.button == 1:
                 self.m_clicked_tones.append(midi_int)
-        else:
-            interval = None
-        self.m_callback(event.button, interval, midi_int)
+            self.m_callback(event.button, interval, midi_int)
     def forget_last_tone(self):
         self.m_clicked_tones.pop()
     def know_directions(self):
@@ -133,6 +134,7 @@ class IntervalPianoWidget(PianoKeyboard):
         for m in self.m_marks.values():
             m.destroy()
         self.m_marks = {}
+        self.m_clicked_tones = []
     def mark(self, midi_int):
         x, y = self.midi_int_to_key(midi_int)
         if not self.m_marks.has_key((x, y)):
@@ -351,9 +353,7 @@ class AbstractGuitarWidget(gnome.canvas.Canvas):
                 interval = midi_int - self.m_clicked_tones[-1]
                 if event.button == 1:
                     self.m_clicked_tones.append(midi_int)
-            else:
-                interval = None
-            self.m_callback(event.button, interval, midi_int)
+                self.m_callback(event.button, interval, midi_int)
     def event2xy(self, event):
         x = event.x - self.m_guitar.get_bounds()[0]
         xp = yp = None
@@ -398,6 +398,7 @@ class AbstractGuitarWidget(gnome.canvas.Canvas):
         for m in self.m_mark_dict.values():
             m.destroy()
         self.m_mark_dict = {}
+        self.m_clicked_tones = []
     def know_directions(self):
         return 1
 
@@ -528,9 +529,7 @@ class AccordionWidget(gnome.canvas.Canvas):
                 interval = midi_int - self.m_clicked_tones[-1]
                 if event.button == 1:
                     self.m_clicked_tones.append(midi_int)
-            else:
-                interval = None
-            self.m_callback(event.button, interval, midi_int)
+                self.m_callback(event.button, interval, midi_int)
     def set_first_note(self, note):
         self.clear()
         self.m_clicked_tones = [int(note)]
@@ -551,9 +550,10 @@ class AccordionWidget(gnome.canvas.Canvas):
                            + n*self.m_button_xdist, rownum*self.m_button_ydist)
                     self.m_mark_dict[(rownum, n)] = g
     def clear(self):
-        for k in self.m_mark_dict.keys():
-            self.m_mark_dict[k].destroy()
-            del self.m_mark_dict[k]
+        for m in self.m_mark_dict.values():
+            m.destroy()
+        self.m_mark_dict = {}
+        self.m_clicked_tones = []
     def know_directions(self):
         return 1
 
