@@ -1,5 +1,5 @@
 # GNU Solfege - eartraining for GNOME
-# Copyright (C) 2000, 2001, 2002  Tom Cato Amundsen
+# Copyright (C) 2000, 2001, 2002, 2003  Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -16,34 +16,32 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 import gtk, gnome, soundcard
-import GDK
-from i18n import _
 import gu, os
 import cfg
 
-class MidiInstrumentMenu(gtk.GtkMenu):
+class MidiInstrumentMenu(gtk.Menu):
     def __init__(self, callback):
-        gtk.GtkMenu.__init__(self)
+        gtk.Menu.__init__(self)
         self.m_callback = callback
         for x in range(len(soundcard.instrument_names)):
             if x % 8 == 0:
-                menuitem = gtk.GtkMenuItem(soundcard.instrument_sections[x/8])
-                submenu = gtk.GtkMenu()
+                menuitem = gtk.MenuItem(soundcard.instrument_sections[x/8])
+                submenu = gtk.Menu()
                 self.append(menuitem)
                 menuitem.set_submenu(submenu)
                 menuitem.show()
-            item = gtk.GtkMenuItem(soundcard.instrument_names[x])
+            item = gtk.MenuItem(soundcard.instrument_names[x])
             item.connect('event', self.menuevent)
             item.set_data('instrument', x)
             submenu.append(item)
             item.show()
         self.show()
     def menuevent(self, _o=None, event=None):
-        if event.type == GDK.BUTTON_RELEASE:
+        if event.type == gtk.gdk.BUTTON_RELEASE:
             self.m_callback(_o.get_data('instrument'))
 
 
-class ReadOnlyInstrumentSelector(gtk.GtkFrame, cfg.ConfigUtils):
+class ReadOnlyInstrumentSelector(gtk.Frame, cfg.ConfigUtils):
     def __init__(self, txt, section, name, on_change_callback=None):
         """
         ReadOnlyInstrumentSelector is used by ConfigWindow, because
@@ -54,42 +52,40 @@ class ReadOnlyInstrumentSelector(gtk.GtkFrame, cfg.ConfigUtils):
         section: what section in config file to use, typically an exercise name
         name: name and name_velocity are used in configfile
         """
-        gtk.GtkFrame.__init__(self, txt)
+        gtk.Frame.__init__(self, txt)
         #cfg.ConfigUtils.__init__(self, section)
         cfg.ConfigUtils.__dict__['__init__'](self, section)
         self.m_name = name
         self.m_on_change_callback = on_change_callback
-        vbox = gtk.GtkVBox()
-        vbox.set_border_width(gnome.uiconsts.PAD_SMALL)
+        vbox = gtk.VBox()
+        vbox.set_border_width(gnome.ui.PAD_SMALL)
         self.add(vbox)
         self.g_button = gu.bButton(vbox,
               soundcard.instrument_names[self.get_int(self.m_name)],
               self.on_btnclick)
         self.g_menu = MidiInstrumentMenu(self.on_instrument_selected)
         self.m_instrument = self.get_int('config/preferred_instrument')
-        if not self.get_int(self.m_name+'_velocity'):
+        if self.get_int(self.m_name+'_velocity')==0:
             self.set_int(self.m_name+'_velocity',
                       self.get_int('config/preferred_instrument_velocity'))
         hbox = gu.bHBox(vbox)
-        hbox.set_spacing(gnome.uiconsts.PAD_SMALL)
-        label = gtk.GtkLabel(_("Velocity:"))
+        hbox.set_spacing(gnome.ui.PAD_SMALL)
+        label = gtk.Label(_("Velocity:"))
         label.set_alignment(1.0, 0.5)
         hbox.pack_start(label)
-        self.g_velocity = gtk.GtkSpinButton(gtk.GtkAdjustment(self.get_int(self.m_name+'_velocity'), 0, 127, 1, 10), digits=0)
-        self.g_velocity.connect('changed', self.spin_callback)
+        self.g_velocity = gtk.SpinButton(gtk.Adjustment(self.get_int(self.m_name+'_velocity'), 0, 127, 1, 10), digits=0)
+        self.g_velocity.connect('value-changed', self.spin_callback)
         ihbox = gu.bHBox(hbox, gtk.FALSE)
         ihbox.pack_start(self.g_velocity, gtk.FALSE)
         btn = gu.bButton(ihbox, None, self.play_selected_instrument, gtk.FALSE)
-        pix, mask = gtk.create_pixmap_from_xpm(btn, None,
-                                       os.path.join("xpm", "test-sound.xpm"))
-        p = gtk.GtkPixmap(pix, mask)
-
-        btn.add(p)
+        im = gtk.Image()
+        im.set_from_file(os.path.join("graphics", "test-sound.png"))
+        btn.add(im)
         self.show_all()
     def on_btnclick(self, *argv):
         self.g_menu.popup(None, None, None, 1, 0)
     def on_instrument_selected(self, instrument=None):
-        self.g_button.children()[0].set_text(soundcard.instrument_names[instrument])
+        self.g_button.get_children()[0].set_text(soundcard.instrument_names[instrument])
         self.m_instrument = instrument
         self.play_selected_instrument()
         if self.m_on_change_callback:
@@ -107,32 +103,32 @@ class InstrumentSelector(ReadOnlyInstrumentSelector):
         self.add_watch(self.m_name, self._instr_cb)
         self.add_watch(self.m_name+'_velocity', self._velocity_cb)
     def _instr_cb(self, name):
-        self.g_button.children()[0].set_text(
+        self.g_button.get_children()[0].set_text(
               soundcard.instrument_names[self.get_int(name)])
     def _velocity_cb(self, name):
         self.g_velocity.set_value(self.get_float(name))
     def on_instrument_selected(self, instrument=None):
         ReadOnlyInstrumentSelector.on_instrument_selected(self, instrument)
-        self.set_int(self.m_name, instrument)        
+        self.set_int(self.m_name, instrument)
     def spin_callback(self, p=None):
         ReadOnlyInstrumentSelector.spin_callback(self, p)
         self.set_int(self.m_name+'_velocity', p.get_value_as_int())
-                                        
-class InstrumentConfigurator(gtk.GtkVBox, cfg.ConfigUtils):
+
+class InstrumentConfigurator(gtk.VBox, cfg.ConfigUtils):
     def __init__(self, exname, num):
-        gtk.GtkVBox.__init__(self)
+        gtk.VBox.__init__(self)
         #cfg.ConfigUtils.__init__(self, exname)
         cfg.ConfigUtils.__dict__['__init__'](self, exname)
         assert num in (2, 3)
         self.m_num = num
         self.g_override_default_instrument_checkbutton \
             = gu.nCheckButton(exname, 'override_default_instrument',
-                 _("Change midi instrument for this exercise"),
+                 _("_Change midi instrument for this exercise"),
                  callback=self.update_instrument_override)
         self.pack_start(self.g_override_default_instrument_checkbutton,
                         gtk.FALSE)
         hbox = gu.bHBox(self)
-        hbox.set_spacing(gnome.uiconsts.PAD_SMALL)
+        hbox.set_spacing(gnome.ui.PAD_SMALL)
 
         self.g_instrsel_high = InstrumentSelector(_("Highest instrument"),
                                                  exname, 'highest_instrument')
