@@ -279,7 +279,7 @@ class MainWin(gnome.ui.App, cfg.ConfigUtils):
                   ["Tom Cato Amundsen",
                   'Oliver Vollmer %s' % _("(toolbar icons)"),
                   'Giovanni Chierico %s' % _("(some lessonfiles)"),
-                  'Mickael Becker %s' % _("(some lessonfiles)"),
+                  'Michael Becker %s' % _("(some lessonfiles)"),
                   'Joe Lee %s' % _("(sound code for the MS Windows port)"),
                   ],
                   ["Tom Cato Amundsen"],
