@@ -259,8 +259,7 @@ class Gui(abstract.Gui):
 
         # action area
         self.g_new = gu.bButton(self.action_area, _("_New"), self.new_question)
-        self.g_repeat = gu.bButton(self.action_area, _("_Repeat"),
-                          lambda btn, self=self: self.m_t.play_question())
+        self.g_repeat = gu.bButton(self.action_area, _("_Repeat"), self.repeat_question)
         self.g_repeat.set_sensitive(gtk.FALSE)
         self.g_show = gu.bButton(self.action_area, _("_Give up"), self.give_up)
         self.g_show.set_sensitive(gtk.FALSE)
@@ -359,6 +358,7 @@ class Gui(abstract.Gui):
             if self.m_t.guess_answer(self.g_rhythm_viewer.m_data):
                 self.g_rhythm_viewer.happy_face()
                 self.g_new.set_sensitive(gtk.TRUE)
+                self.g_new.grab_focus()
                 self.g_backspace.set_sensitive(gtk.FALSE)
                 self.g_show.set_sensitive(gtk.FALSE)
             else:
@@ -388,6 +388,9 @@ class Gui(abstract.Gui):
             assert g == Teacher.ERR_NO_ELEMS
             self.g_repeat.set_sensitive(gtk.FALSE)
             self.g_rhythm_viewer.flash(_("You have to configure this exercise properly"))
+    def repeat_question(self, *w):
+        self.m_t.play_question()
+        self.g_first_rhythm_button.grab_focus()
     def on_start_practise(self):
         self.g_rhythm_viewer.flash(_("Click 'New' to begin."))
         self.g_new.grab_focus()
