@@ -23,10 +23,10 @@ class TracebackWindow(gtk.Dialog):
         gtk.Dialog.__init__(self)
         self.set_default_size(630, 400)
         self.vbox.set_border_width(8)
-        label = gtk.Label(_("Program error"))
-        label.set_name('Heading1')
+        label = gtk.Label(_("GNU Solfege message window"))
+        label.set_name('Heading2')
         self.vbox.pack_start(label, gtk.FALSE)
-        label = gtk.Label(_("Hm... *something* is wrong. You should report this to bug-solfege@gnu.org or solfege-devel@lists.sourceforge.net if you think this is a bug in Solfege."))
+        label = gtk.Label(_("Please report to bug-solfege@gnu.org if the content of the message make you believe you have found a bug."))
         label.set_line_wrap(gtk.TRUE)
         self.vbox.pack_start(label, gtk.FALSE)
         scrollwin = gtk.ScrolledWindow()
