@@ -48,7 +48,8 @@ def int_to_intervalname(i, shortname=None, updown=None):
 
 
 def filter_intervals_within_range(lowest, highest, irange):
-    assert type(lowest) == type(highest) == types.StringType
+    assert type(lowest) in types.StringTypes
+    assert type(highest) in types.StringTypes
     lowest = mpd.notename_to_int(lowest)
     highest = mpd.notename_to_int(highest)
     i = highest - lowest
@@ -63,9 +64,9 @@ def random_interval(tonika, lowest, highest, irange):
         tonika = tonika.semitone_pitch()
     assert type(tonika) == types.IntType
     assert type(lowest) == type(highest)
-    if type(lowest) == types.StringType:
+    if type(lowest) in types.StringTypes:
         lowest = mpd.notename_to_int(lowest)
-    if type(highest) == types.StringType:
+    if type(highest) in types.StringTypes:
         highest = mpd.notename_to_int(highest)
     assert type(lowest) == type(highest) == types.IntType
     assert lowest <= highest
@@ -91,9 +92,9 @@ def random_tonika_and_interval(lowest, highest, irange):
              second up, -2 is major second down
     """
     assert type(lowest) == type(highest)
-    if type(lowest) == types.StringType:
+    if type(lowest) in types.StringTypes:
         lowest = mpd.notename_to_int(lowest)
-    if type(highest) == types.StringType:
+    if type(highest) == types.StringTypes:
         highest = mpd.notename_to_int(highest)
     assert type(lowest) == type(highest) == types.IntType
     assert lowest <= highest
@@ -122,7 +123,8 @@ def adjust_low_high_to_irange(lowest, highest, irange):
              second up, -2 is major second down
     return tuple with two integers
     """
-    assert type(lowest) == type(lowest) == types.StringType
+    assert type(lowest) in types.StringTypes
+    assert type(highest) in types.StringTypes
     L = mpd.notename_to_int(lowest)
     H = mpd.notename_to_int(highest)
     # find the largest interval that can be asked for
@@ -175,7 +177,7 @@ def get_modifier(s):
          ('<shift>', gtk.gdk.SHIFT_MASK),
          ('<alt>', 8))#gtk.gdk.MOD1_MASK))
     for mod, mask in m:
-        if s[:len(mod)] == mod:
+        if s.startswith(mod):
             return mask, s[len(mod):]
     return None, s
 
